@@ -16,9 +16,10 @@
 import json
 import locale
 import os
-from oslo.config import cfg
 import stat
 
+from oslo.config import cfg
+
 from os_collect_config import exc
 from os_collect_config.openstack.common import log
 
@@ -59,6 +60,11 @@ class Collector(object):
             raise exc.LocalMetadataNotAvailable
         final_content = []
         for local_path in cfg.CONF.local.path:
+            try:
+                os.stat(local_path)
+            except OSError:
+                logger.warn("%s not found. Skipping", local_path)
+                continue
             if _dest_looks_insecure(local_path):
                 raise exc.LocalMetadataNotAvailable
             for data_file in os.listdir(local_path):
