@@ -14,16 +14,16 @@
 # limitations under the License.
 
 import copy
-import extras
-import fixtures
 import json
-import mock
 import os
 import signal
 import sys
 import tempfile
 
+import extras
+import fixtures
 from keystoneclient import discover as ks_discover
+import mock
 from oslo.config import cfg
 import testtools
 from testtools import matchers
@@ -35,9 +35,11 @@ from os_collect_config.tests import test_cfn
 from os_collect_config.tests import test_ec2
 from os_collect_config.tests import test_heat
 from os_collect_config.tests import test_heat_local
+from os_collect_config.tests import test_local
+from os_collect_config.tests import test_request
 
 
-def _setup_local_metadata(test_case):
+def _setup_heat_local_metadata(test_case):
     test_case.useFixture(fixtures.NestedTempfile())
     local_md = tempfile.NamedTemporaryFile(delete=False)
     local_md.write(json.dumps(test_heat_local.META_DATA).encode('utf-8'))
@@ -45,6 +47,15 @@ def _setup_local_metadata(test_case):
     return local_md.name
 
 
+def _setup_local_metadata(test_case):
+    tmpdir = fixtures.TempDir()
+    test_case.useFixture(tmpdir)
+    local_data_path = tmpdir.path + '/local'
+    with open(local_data_path, 'w') as local_data:
+        json.dump(test_local.META_DATA, local_data)
+    return tmpdir.path
+
+
 class TestCollect(testtools.TestCase):
 
     def setUp(self):
@@ -63,7 +74,8 @@ class TestCollect(testtools.TestCase):
             'heat': {
                 'keystoneclient': test_heat.FakeKeystoneClient(self),
                 'heatclient': test_heat.FakeHeatClient(self)
-            }
+            },
+            'request': {'requests_impl': test_request.FakeRequests},
         }
         return collect.__main__(args=fake_args,
                                 collector_kwargs_map=collector_kwargs_map)
@@ -82,7 +94,7 @@ class TestCollect(testtools.TestCase):
         expected_cmd = self.getUniqueString()
         cache_dir = self.useFixture(fixtures.TempDir())
         backup_cache_dir = self.useFixture(fixtures.TempDir())
-        fake_metadata = _setup_local_metadata(self)
+        fake_metadata = _setup_heat_local_metadata(self)
         occ_args = [
             'os-collect-config',
             '--command',
@@ -144,7 +156,7 @@ class TestCollect(testtools.TestCase):
             self.assertIn("map_ab", keys_found)
 
     def test_main_just_local(self):
-        fake_md = _setup_local_metadata(self)
+        fake_md = _setup_heat_local_metadata(self)
         occ_args = [
             'os-collect-config',
             '--print',
@@ -156,7 +168,7 @@ class TestCollect(testtools.TestCase):
     def test_main_force_command(self):
         cache_dir = self.useFixture(fixtures.TempDir())
         backup_cache_dir = self.useFixture(fixtures.TempDir())
-        fake_metadata = _setup_local_metadata(self)
+        fake_metadata = _setup_heat_local_metadata(self)
         occ_args = [
             'os-collect-config',
             '--command', 'foo',
@@ -176,7 +188,7 @@ class TestCollect(testtools.TestCase):
     def test_main_command_failed_no_caching(self):
         cache_dir = self.useFixture(fixtures.TempDir())
         backup_cache_dir = self.useFixture(fixtures.TempDir())
-        fake_metadata = _setup_local_metadata(self)
+        fake_metadata = _setup_heat_local_metadata(self)
         occ_args = [
             'os-collect-config',
             '--command',
@@ -218,7 +230,7 @@ class TestCollect(testtools.TestCase):
             '--cfn-secret-access-key',
             'FEDCBA9876543210',
         ]
-        fake_metadata = _setup_local_metadata(self)
+        fake_metadata = _setup_heat_local_metadata(self)
         fake_args.append('--heat_local-path')
         fake_args.append(fake_metadata)
         output = self.useFixture(fixtures.StringStream('stdout'))
@@ -249,7 +261,7 @@ class TestCollect(testtools.TestCase):
     def test_main_print_only(self):
         cache_dir = self.useFixture(fixtures.TempDir())
         backup_cache_dir = self.useFixture(fixtures.TempDir())
-        fake_metadata = _setup_local_metadata(self)
+        fake_metadata = _setup_heat_local_metadata(self)
         args = [
             'os-collect-config',
             '--command', 'bar',
@@ -331,13 +343,15 @@ class TestCollectAll(testtools.TestCase):
         cfg.CONF.cfn.path = ['foo.Metadata']
         cfg.CONF.cfn.access_key_id = '0123456789ABCDEF'
         cfg.CONF.cfn.secret_access_key = 'FEDCBA9876543210'
-        cfg.CONF.heat_local.path = [_setup_local_metadata(self)]
+        cfg.CONF.heat_local.path = [_setup_heat_local_metadata(self)]
         cfg.CONF.heat.auth_url = 'http://127.0.0.1:5000/v3'
         cfg.CONF.heat.user_id = '0123456789ABCDEF'
         cfg.CONF.heat.password = 'FEDCBA9876543210'
         cfg.CONF.heat.project_id = '9f6b09df-4d7f-4a33-8ec3-9924d8f46f10'
         cfg.CONF.heat.stack_id = 'a/c482680f-7238-403d-8f76-36acf0c8e0aa'
         cfg.CONF.heat.resource_name = 'server'
+        cfg.CONF.local.path = [_setup_local_metadata(self)]
+        cfg.CONF.request.metadata_url = 'http://127.0.0.1:8000/my_metadata/'
 
     @mock.patch.object(ks_discover.Discover, '__init__')
     @mock.patch.object(ks_discover.Discover, 'url_for')
@@ -352,7 +366,8 @@ class TestCollectAll(testtools.TestCase):
                 'heat': {
                     'keystoneclient': test_heat.FakeKeystoneClient(self),
                     'heatclient': test_heat.FakeHeatClient(self)
-                }
+                },
+                'request': {'requests_impl': test_request.FakeRequests},
             }
         if collectors is None:
             collectors = cfg.CONF.collectors
@@ -366,7 +381,8 @@ class TestCollectAll(testtools.TestCase):
         (changed_keys, paths) = self._call_collect_all(
             store=True, collector_kwargs_map=collector_kwargs_map)
         if expected_changed is None:
-            expected_changed = set(['heat_local', 'cfn', 'ec2', 'heat'])
+            expected_changed = set(['heat_local', 'cfn', 'ec2',
+                                    'heat', 'local', 'request'])
         self.assertEqual(expected_changed, changed_keys)
         self.assertThat(paths, matchers.IsInstance(list))
         for path in paths:
@@ -384,10 +400,11 @@ class TestCollectAll(testtools.TestCase):
             'heat': {
                 'keystoneclient': test_heat.FakeKeystoneClient(self),
                 'heatclient': test_heat.FakeHeatClient(self)
-            }
+            },
+            'request': {'requests_impl': test_request.FakeRequests},
         }
         expected_changed = set((
-            'heat_local', 'ec2', 'cfn', 'heat',
+            'heat_local', 'ec2', 'cfn', 'heat', 'local', 'request',
             'dep-name1', 'dep-name2', 'dep-name3'))
         self._test_collect_all_store(collector_kwargs_map=soft_config_map,
                                      expected_changed=expected_changed)
@@ -422,7 +439,8 @@ class TestCollectAll(testtools.TestCase):
             'heat': {
                 'keystoneclient': test_heat.FakeKeystoneClient(self),
                 'heatclient': test_heat.FakeHeatClient(self)
-            }
+            },
+            'request': {'requests_impl': test_request.FakeRequests},
         }
         (changed_keys, paths) = self._call_collect_all(
             store=True, collector_kwargs_map=soft_config_map)
